<?php
	
	/**
		* Mystem Navigation Menu Widget
		*
		* @package WordPress
		* @subpackage MyStem
		* @since MyStem 1.2.1
 */
	
	class MyStem_Nav_Menu_Widget extends WP_Widget {
		
		/**
			* Sets up a new Navigation Menu widget instance.
			*
			* @since 3.0.0
		*/
		public function __construct() {
			
			parent::__construct(
			'mystem_nav_menu_widget',
			__( 'MyStem Navigation Menu', 'mystem' ),
			array(
			'description' =>__( 'Add a navigation menu (without dropdown) to sidebar', 'mystem' ),
			)
			);
		}
		
		/**
			* Outputs the content for the current Navigation Menu widget instance.
			*
			* @since 3.0.0
			*
			* @param array $args     Display arguments including 'before_title', 'after_title',
			*                        'before_widget', and 'after_widget'.
			* @param array $instance Settings for the current Navigation Menu widget instance.
		*/
		public function widget( $args, $instance ) {
			// Get menu
			
			$args['id'] = ( isset( $args['id'] ) ) ? $args['id'] : 'mystem_nav_menu_widget';		
			$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Navigation menu', 'mystem' );
			$title = apply_filters( 'widget_title', $instance['title'], $instance, $args['id'] );
			
			$nav_menu = ! empty( $instance['nav_menu'] ) ? wp_get_nav_menu_object( $instance['nav_menu'] ) : false;
			
			if ( ! $nav_menu ) {
				return;
			}
			
			
			
			
			$nav_menu_args = array(
				'fallback_cb' => '',
				'menu'        => $nav_menu,
				'container' => false,
				'menu_class' => 'dropdown hover-effect',	
				'depth'           => 1,				
			);
			
			/**
				* Filters the arguments for the Navigation Menu widget.
				*
				* @since 4.2.0
				* @since 4.4.0 Added the `$instance` parameter.
				*
				* @param array    $nav_menu_args {
				*     An array of arguments passed to wp_nav_menu() to retrieve a navigation menu.
				*
				*     @type callable|bool $fallback_cb Callback to fire if the menu doesn't exist. Default empty.
				*     @type mixed         $menu        Menu ID, slug, or name.
				* }
				* @param WP_Term  $nav_menu      Nav menu object for the current menu.
				* @param array    $args          Display arguments for the current widget.
				* @param array    $instance      Array of settings for the current widget.
			*/
			echo $args['before_widget'];
			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}
			wp_nav_menu( apply_filters( 'widget_nav_menu_args', $nav_menu_args, $nav_menu, $args, $instance ) );
			echo $args['after_widget'];
		}
		
		
		
		/**
			* Handles updating settings for the current Navigation Menu widget instance.
			*
			* @since 3.0.0
			*
			* @param array $new_instance New settings for this instance as input by the user via
			*                            WP_Widget::form().
			* @param array $old_instance Old settings for this instance.
			* @return array Updated settings to save.
		*/
		public function update( $new_instance, $old_instance ) {
			$instance = $old_instance;
			$instance['title'] = strip_tags( $new_instance['title'] );	
			
			if ( ! empty( $new_instance['nav_menu'] ) ) {
				$instance['nav_menu'] = (int) $new_instance['nav_menu'];
			}
			
			
			
			return $instance;
		}
		
		/**
			* Outputs the settings form for the Navigation Menu widget.
			*
			* @since 3.0.0
			*
			* @param array $instance Current settings.
			* @global WP_Customize_Manager $wp_customize
		*/
		public function form( $instance ) {
	
			$title = isset( $instance['title'] ) ? $instance['title'] : 'Navigation menu';
			$nav_menu = isset( $instance['nav_menu'] ) ? $instance['nav_menu'] : '';			
			
			// Get menus
			$menus = wp_get_nav_menus();
			
			// If no menus exists, direct the user to go and create some.
		?>
		
		<div class="nav-menu-widget-form-controls">
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'mystem' ) ?>:</label>
				<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $title ); ?>"/>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'nav_menu' ); ?>"><?php _e( 'Select Menu', 'mystem' ); ?>:</label>
				<select id="<?php echo $this->get_field_id( 'nav_menu' ); ?>" name="<?php echo $this->get_field_name( 'nav_menu' ); ?>">
					<option value="0"><?php _e( 'Select', 'mystem' ); ?></option>
					<?php foreach ( $menus as $menu ) : ?>
					<option value="<?php echo esc_attr( $menu->term_id ); ?>" <?php selected( $nav_menu, $menu->term_id ); ?>>
						<?php echo esc_html( $menu->name ); ?>
					</option>
					<?php endforeach; ?>
				</select>
			</p>            
			
		</div>
		
		
		
		<?php
		}
	}
